==> react-fetching-library-1.6.2.tgz: package/lib/index.js <==
/*
 *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
*****************************************************************************/
'use strict';Object.defineProperty(exports,"__esModule",{value:!0});function _interopDefault(a){return a&&"object"===typeof a&&"default"in a?a["default"]:a}var React=require("react"),React__default=_interopDefault(React),extendStatics=function(a,b){extendStatics=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(a,b){a.__proto__=b}||function(a,b){for(var d in b)b.hasOwnProperty(d)&&(a[d]=b[d])};return extendStatics(a,b)};
function __extends(a,b){function f(){this.constructor=a}extendStatics(a,b);a.prototype=null===b?Object.create(b):(f.prototype=b.prototype,new f)}var __assign=function(){__assign=Object.assign||function(a){for(var b,f=1,c=arguments.length;f<c;f++){b=arguments[f];for(var d in b)Object.prototype.hasOwnProperty.call(b,d)&&(a[d]=b[d])}return a};return __assign.apply(this,arguments)};
function __rest(a,b){var f={},c;for(c in a)Object.prototype.hasOwnProperty.call(a,c)&&0>b.indexOf(c)&&(f[c]=a[c]);if(null!=a&&"function"===typeof Object.getOwnPropertySymbols){var d=0;for(c=Object.getOwnPropertySymbols(a);d<c.length;d++)0>b.indexOf(c[d])&&(f[c[d]]=a[c[d]])}return f}
function __awaiter(a,b,f,c){return new (f||(f=Promise))(function(d,h){function g(a){try{k(c.next(a))}catch(l){h(l)}}function e(a){try{k(c["throw"](a))}catch(l){h(l)}}function k(a){a.done?d(a.value):(new f(function(b){b(a.value)})).then(g,e)}k((c=c.apply(a,b||[])).next())})}
function __generator(a,b){function f(a){return function(b){return c([a,b])}}function c(c){if(h)throw new TypeError("Generator is already executing.");for(;d;)try{if(h=1,g&&(e=c[0]&2?g["return"]:c[0]?g["throw"]||((e=g["return"])&&e.call(g),0):g.next)&&!(e=e.call(g,c[1])).done)return e;if(g=0,e)c=[c[0]&2,e.value];switch(c[0]){case 0:case 1:e=c;break;case 4:return d.label++,{value:c[1],done:!1};case 5:d.label++;g=c[1];c=[0];continue;case 7:c=d.ops.pop();d.trys.pop();continue;default:if(!(e=d.trys,e=
0<e.length&&e[e.length-1])&&(6===c[0]||2===c[0])){d=0;continue}if(3===c[0]&&(!e||c[1]>e[0]&&c[1]<e[3]))d.label=c[1];else if(6===c[0]&&d.label<e[1])d.label=e[1],e=c;else if(e&&d.label<e[2])d.label=e[2],d.ops.push(c);else{e[2]&&d.ops.pop();d.trys.pop();continue}}c=b.call(a,d)}catch(l){c=[6,l],g=0}finally{h=e=0}if(c[0]&5)throw c[1];return{value:c[0]?c[1]:void 0,done:!0}}var d={label:0,sent:function(){if(e[0]&1)throw e[1];return e[1]},trys:[],ops:[]},h,g,e,k;return k={next:f(0),"throw":f(1),"return":f(2)},
"function"===typeof Symbol&&(k[Symbol.iterator]=function(){return this}),k}
var convertActionToBase64=function(a){return Buffer.from(JSON.stringify(a)).toString("base64")},createCache=function(a,b){var f={},c=function(a){delete f[convertActionToBase64(a)]};return{add:function(c,b){a(c)&&(f[convertActionToBase64(c)]=__assign(__assign({},b),{timestamp:Date.now()}))},get:function(a){var d=f[convertActionToBase64(a)],g=d&&b(d);if(g)return d;d&&!g&&c(a)},getItems:function(){return f},remove:c,setItems:function(a){f=a}}},QueryError=function(a){function b(f,c){f=a.call(this,f)||
this;Object.setPrototypeOf(f,b.prototype);f.name="QueryError";f.response=c;return f}__extends(b,a);return b}(Error),createClient=function(a){void 0===a&&(a={});var b=a.cacheProvider,f=createCache(function(){return!0},function(){return!0}),c=function(a,b){return __awaiter(void 0,void 0,void 0,function(){var f,d,e,g;return __generator(this,function(m){switch(m.label){case 0:f=b[0];d=b.slice(1);if(!f)return[3,3];g=c;return[4,f(h)(a)];case 1:return[4,g.apply(void 0,[m.sent(),d])];case 2:return e=m.sent(),
[3,4];case 3:e=a,m.label=4;case 4:return[2,e]}})})},d=function(a,c,b){return __awaiter(void 0,void 0,void 0,function(){var f,e,g,m,k;return __generator(this,function(l){switch(l.label){case 0:f=b[0];e=b.slice(1);if(!f)return[3,3];m=d;k=[a];return[4,f(h)(a,c)];case 1:return[4,m.apply(void 0,k.concat([l.sent(),e]))];case 2:return g=l.sent(),[3,4];case 3:g=c,l.label=4;case 4:return[2,g]}})})},h={cache:b,query:function(f,e){void 0===e&&(e=!1);return __awaiter(void 0,void 0,void 0,function(){var g,h,l,
t,m,n,p,w,x,q,r,y,z,u,A;return __generator(this,function(k){switch(k.label){case 0:return k.trys.push([0,5,,6]),[4,c(f,a.requestInterceptors||[])];case 1:g=k.sent();h=g.endpoint;l=g.body;t=g.responseType;m=__rest(g,["endpoint","body","responseType"]);if(b&&!e&&(n=b.get(f)))return[2,n];p=m.headers;l&&(l instanceof FormData||l instanceof Blob||l instanceof ArrayBuffer)||(p=__assign({"Content-Type":"application/json; charset=utf-8"},m.headers));w=p&&p["Content-Type"]&&-1!==p["Content-Type"].indexOf("json");
x=a.fetch||fetch;return[4,x(h,{body:l?w?JSON.stringify(l):l:void 0,cache:m.cache,credentials:m.credentials,headers:p,integrity:m.integrity,keepalive:m.keepalive,method:m.method,mode:m.mode,redirect:m.redirect,referrer:m.referrer,referrerPolicy:m.referrerPolicy,signal:m.signal,window:m.window})];case 2:return q=k.sent(),y=d,z=[g],u={error:!q.ok,headers:q.headers},[4,resolveResponse(q,t)];case 3:return[4,y.apply(void 0,z.concat([(u.payload=k.sent(),u.status=q.status,u),a.responseInterceptors||[]]))];
case 4:r=k.sent();b&&q.ok&&b.add(f,r);if(r.status&&g.config&&g.config.emitErrorForStatuses&&g.config.emitErrorForStatuses.includes(r.status))throw new QueryError("request-error",r);return[2,r];case 5:return A=k.sent(),[2,{error:!0,errorObject:A}];case 6:return[2]}})})},suspenseCache:f};return h};
function resolveResponse(a,b){return __awaiter(this,void 0,void 0,function(){var f,c,d,h;return __generator(this,function(g){switch(g.label){case 0:return b?[2,a[b]()]:[3,1];case 1:return f=[204,205],c=a.headers.get("Content-Type"),(d=-1===f.indexOf(a.status)&&c&&-1!==c.indexOf("json"))?[4,a.json()]:[3,3];case 2:return h=g.sent(),[3,5];case 3:return[4,a.text()];case 4:h=g.sent(),g.label=5;case 5:return[2,h]}})})}
var initialContext={query:function(){console.warn("Add ClientProvider to use client context");return Promise.resolve({error:!0,status:0})},suspenseCache:createCache(function(){return!0},function(){return!0})},ClientContext=React.createContext(initialContext),SET_LOADING="response/loading",RESET_LOADING="response/reset-loading",RESET="response/reset",SET_RESPONSE="response/set",responseReducer=function(a,b){switch(b.type){case SET_LOADING:return __assign(__assign({},a),{loading:!0});case RESET_LOADING:return __assign(__assign({},
a),{loading:!1});case SET_RESPONSE:if(!b.response)throw Error();return __assign(__assign({},a),{loading:!1,response:b.response});case RESET:return{loading:!1,response:{error:!1}};default:throw Error();}},useCachedResponse=function(a){var b=React.useContext(ClientContext);if(b.cache)return b.cache.get(a)},useQuery=function(a,b){void 0===b&&(b=!0);var f=React.useContext(ClientContext),c=useCachedResponse(a),d=React.useRef(!0),h=React.useRef(),g=React.useReducer(responseReducer,{loading:c?!1:b,response:c?
c:{error:!1}}),e=g[0],k=g[1];React.useEffect(function(){d.current=!0;b&&!c&&v();return function(){d.current=!1;l()}},[convertActionToBase64(a)]);var v=React.useCallback(function(c){void 0===c&&(c=!1);return __awaiter(void 0,void 0,void 0,function(){var b,g,e;return __generator(this,function(l){switch(l.label){case 0:b="AbortController"in window?new AbortController:void 0;g=a.signal||(b?b.signal:void 0);h.current&&h.current.abort();h.current=b;if(!d.current)return[2,{error:!1}];k({type:SET_LOADING});
return[4,f.query(__assign(__assign({},a),{signal:a.signal||g}),c)];case 1:return e=l.sent(),!d.current||e.errorObject&&"AbortError"===e.errorObject.name||k({type:SET_RESPONSE,response:e}),d.current&&e.errorObject&&"AbortError"===e.errorObject.name&&h.current&&h.current===b&&(h.current=void 0,k({type:RESET_LOADING})),[2,e]}})})},[convertActionToBase64(a)]);g=React.useCallback(function(){return v(!0)},[convertActionToBase64(a)]);var l=React.useCallback(function(){h.current&&h.current.abort()},[]),t=
React.useCallback(function(){k({type:RESET})},[]);if(e.response&&e.response.errorObject&&e.response.errorObject instanceof QueryError)throw e.response.errorObject;return __assign({abort:l,loading:e.loading,query:g,reset:t},e.response)},useMutation=function(a){var b=React.useContext(ClientContext),f=React.useRef(!0),c=React.useRef(),d=React.useReducer(responseReducer,{loading:!1,response:{error:!1}}),h=d[0],g=d[1];React.useEffect(function(){f.current=!0;return function(){f.current=!1;e()}},[]);d=React.useCallback(function(){for(var e=
[],d=0;d<arguments.length;d++)e[d]=arguments[d];return __awaiter(void 0,void 0,void 0,function(){var d,h,l,k;return __generator(this,function(m){switch(m.label){case 0:if(!f.current)return[2,{error:!1}];d=a.apply(void 0,e);h="AbortController"in window?new AbortController:void 0;l=d.signal||(h?h.signal:void 0);c.current&&c.current.abort();c.current=h;g({type:SET_LOADING});return[4,b.query(__assign(__assign({},d),{signal:d.signal||l}))];case 1:return k=m.sent(),!f.current||k.errorObject&&"AbortError"===
k.errorObject.name||g({type:SET_RESPONSE,response:k}),f.current&&k.errorObject&&"AbortError"===k.errorObject.name&&c.current&&c.current===h&&(c.current=void 0,g({type:RESET_LOADING})),[2,k]}})})},[a]);var e=React.useCallback(function(){c.current&&c.current.abort()},[]),k=React.useCallback(function(){g({type:RESET})},[]);if(h.response&&h.response.errorObject&&h.response.errorObject instanceof QueryError)throw h.response.errorObject;return __assign({abort:e,loading:h.loading,mutate:d,reset:k},h.response)},
useBulkMutation=function(a){var b=React.useContext(ClientContext).query,f=React.useRef(!0),c=React.useRef(),d=React.useState({loading:!1,responses:[]}),h=d[0],g=d[1],e=React.useCallback(function(){c.current&&c.current.abort()},[c]);React.useEffect(function(){f.current=!0;return function(){f.current=!1;e()}},[e]);d=React.useCallback(function(d){return __awaiter(void 0,void 0,void 0,function(){var e,h,k,n;return __generator(this,function(l){switch(l.label){case 0:if(!f.current)return[2,Array.from(Array(10).keys()).map(function(){return{error:!1}})];
e="AbortController"in window?new AbortController:void 0;h=d.map(function(b){return a(b)});k=e?e.signal:void 0;h.forEach(function(a){return a.signal=a.signal||k});c.current&&c.current.abort();c.current=e;g(function(a){return __assign(__assign({},a),{loading:!0})});return[4,Promise.all(h.map(function(a){return b(a)}))];case 1:return n=l.sent(),f.current&&g({loading:!1,responses:n.map(function(a,b){if(!a.errorObject||"AbortError"!==a.errorObject.name)return h[b].signal===k&&c.current===e&&(c.current=
void 0,g(function(a){return __assign(__assign({},a),{loading:!1})})),a})}),[2,n]}})})},[b,a]);var k=React.useCallback(function(){g({loading:!1,responses:[]})},[g]);return{abort:e,loading:h.loading,mutate:d,reset:k,responses:h.responses}},useSuspenseQuery=function(a){var b=React.useContext(ClientContext),f=React.useState(null),c=f[0],d=f[1],h=b.suspenseCache.get(a);React.useEffect(function(){h&&h.response&&null!==c&&b.suspenseCache.remove(a);return function(){b.suspenseCache.remove(a)}},[convertActionToBase64(a)]);
f=function(){b.suspenseCache.remove(a);d(!c)};if(h){if(h.response){if(h.response.errorObject&&h.response.errorObject instanceof QueryError)throw h.response.errorObject;return __assign(__assign({},h.response),{query:f})}throw h.fetch;}var g=b.query(a,null!==c).then(function(c){b.suspenseCache.add(a,{fetch:g,response:c})});b.suspenseCache.add(a,{fetch:g});throw g;},useClient=function(){return React.useContext(ClientContext)},useParameterizedQuery=function(a){var b=useMutation(a);a=b.mutate;b=__rest(b,
["mutate"]);return __assign(__assign({},b),{query:a})},Query=function(a){var b=a.children,f=a.initFetch;a=useQuery(a.action,void 0===f?!0:f);return b(a)},Mutation=function(a){var b=a.children;a=useMutation(a.actionCreator);return b(a)},SuspenseQuery=function(a){var b=a.children;a=useSuspenseQuery(a.action);return b(a)},QueryErrorBoundary=function(a){function b(b){var c=a.call(this,b)||this;c.state={hasError:!1};c.restart=function(){c.setState({hasError:!1,response:void 0})};c.state={hasError:!1,response:void 0};
return c}__extends(b,a);b.getDerivedStateFromError=function(a){if(a instanceof QueryError)return{hasError:!0,response:a.response}};b.prototype.render=function(){return this.state.hasError&&this.state.response&&this.state.response.status&&this.props.statuses.includes(this.state.response.status)?this.props.fallback(this.state.response,this.restart):this.props.children};return b}(React.Component),ClientContextProvider=function(a){var b=a.client;return React__default.createElement(ClientContext.Provider,
{value:{query:b.query,cache:b.cache,suspenseCache:b.suspenseCache}},a.children)};exports.ClientContext=ClientContext;exports.ClientContextProvider=ClientContextProvider;exports.Mutation=Mutation;exports.Query=Query;exports.QueryError=QueryError;exports.QueryErrorBoundary=QueryErrorBoundary;exports.SuspenseQuery=SuspenseQuery;exports.convertActionToBase64=convertActionToBase64;exports.createCache=createCache;exports.createClient=createClient;exports.useBulkMutation=useBulkMutation;
exports.useCachedResponse=useCachedResponse;exports.useClient=useClient;exports.useMutation=useMutation;exports.useParameterizedQuery=useParameterizedQuery;exports.useQuery=useQuery;exports.useSuspenseQuery=useSuspenseQuery;

==> react-fetching-library-1.7.1.tgz: package/lib/index.js <==
/*
 *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
*****************************************************************************/
'use strict';Object.defineProperty(exports,"__esModule",{value:!0});function _interopDefault(a){return a&&"object"===typeof a&&"default"in a?a["default"]:a}var React=require("react"),React__default=_interopDefault(React),extendStatics=function(a,b){extendStatics=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(a,b){a.__proto__=b}||function(a,b){for(var d in b)b.hasOwnProperty(d)&&(a[d]=b[d])};return extendStatics(a,b)};
function __extends(a,b){function f(){this.constructor=a}extendStatics(a,b);a.prototype=null===b?Object.create(b):(f.prototype=b.prototype,new f)}var __assign=function(){__assign=Object.assign||function(a){for(var b,f=1,c=arguments.length;f<c;f++){b=arguments[f];for(var d in b)Object.prototype.hasOwnProperty.call(b,d)&&(a[d]=b[d])}return a};return __assign.apply(this,arguments)};
function __rest(a,b){var f={},c;for(c in a)Object.prototype.hasOwnProperty.call(a,c)&&0>b.indexOf(c)&&(f[c]=a[c]);if(null!=a&&"function"===typeof Object.getOwnPropertySymbols){var d=0;for(c=Object.getOwnPropertySymbols(a);d<c.length;d++)0>b.indexOf(c[d])&&(f[c[d]]=a[c[d]])}return f}
function __awaiter(a,b,f,c){return new (f||(f=Promise))(function(d,h){function g(a){try{k(c.next(a))}catch(l){h(l)}}function e(a){try{k(c["throw"](a))}catch(l){h(l)}}function k(a){a.done?d(a.value):(new f(function(b){b(a.value)})).then(g,e)}k((c=c.apply(a,b||[])).next())})}
function __generator(a,b){function f(a){return function(b){return c([a,b])}}function c(c){if(h)throw new TypeError("Generator is already executing.");for(;d;)try{if(h=1,g&&(e=c[0]&2?g["return"]:c[0]?g["throw"]||((e=g["return"])&&e.call(g),0):g.next)&&!(e=e.call(g,c[1])).done)return e;if(g=0,e)c=[c[0]&2,e.value];switch(c[0]){case 0:case 1:e=c;break;case 4:return d.label++,{value:c[1],done:!1};case 5:d.label++;g=c[1];c=[0];continue;case 7:c=d.ops.pop();d.trys.pop();continue;default:if(!(e=d.trys,e=
0<e.length&&e[e.length-1])&&(6===c[0]||2===c[0])){d=0;continue}if(3===c[0]&&(!e||c[1]>e[0]&&c[1]<e[3]))d.label=c[1];else if(6===c[0]&&d.label<e[1])d.label=e[1],e=c;else if(e&&d.label<e[2])d.label=e[2],d.ops.push(c);else{e[2]&&d.ops.pop();d.trys.pop();continue}}c=b.call(a,d)}catch(l){c=[6,l],g=0}finally{h=e=0}if(c[0]&5)throw c[1];return{value:c[0]?c[1]:void 0,done:!0}}var d={label:0,sent:function(){if(e[0]&1)throw e[1];return e[1]},trys:[],ops:[]},h,g,e,k;return k={next:f(0),"throw":f(1),"return":f(2)},
"function"===typeof Symbol&&(k[Symbol.iterator]=function(){return this}),k}
var convertActionToBase64=function(a){return Buffer.from(JSON.stringify(a)).toString("base64")},createCache=function(a,b){var f={},c=function(a){delete f[convertActionToBase64(a)]};return{add:function(c,b){a(c)&&(f[convertActionToBase64(c)]=__assign(__assign({},b),{timestamp:Date.now()}))},get:function(a){var d=f[convertActionToBase64(a)],g=d&&b(d);if(g)return d;d&&!g&&c(a)},getItems:function(){return f},remove:c,setItems:function(a){f=a}}},QueryError=function(a){function b(f,c){f=a.call(this,f)||
this;Object.setPrototypeOf(f,b.prototype);f.name="QueryError";f.response=c;return f}__extends(b,a);return b}(Error),createClient=function(a){void 0===a&&(a={});var b=a.cacheProvider,f=createCache(function(){return!0},function(){return!0}),c=function(a,b){return __awaiter(void 0,void 0,void 0,function(){var f,d,e,g;return __generator(this,function(l){switch(l.label){case 0:f=b[0];d=b.slice(1);if(!f)return[3,3];g=c;return[4,f(h)(a)];case 1:return[4,g.apply(void 0,[l.sent(),d])];case 2:return e=l.sent(),
[3,4];case 3:e=a,l.label=4;case 4:return[2,e]}})})},d=function(a,c,b){return __awaiter(void 0,void 0,void 0,function(){var f,e,g,k,m;return __generator(this,function(l){switch(l.label){case 0:f=b[0];e=b.slice(1);if(!f)return[3,3];k=d;m=[a];return[4,f(h)(a,c)];case 1:return[4,k.apply(void 0,m.concat([l.sent(),e]))];case 2:return g=l.sent(),[3,4];case 3:g=c,l.label=4;case 4:return[2,g]}})})},h={cache:b,query:function(f,e){void 0===e&&(e=!1);return __awaiter(void 0,void 0,void 0,function(){var g,h,l,
t,u,m,n,r,x,p,q,y,z,v,A;return __generator(this,function(k){switch(k.label){case 0:return k.trys.push([0,5,,6]),[4,c(f,a.requestInterceptors||[])];case 1:g=k.sent();h=g.endpoint;l=g.body;t=g.responseType;u=__rest(g,["endpoint","body","responseType"]);if(b&&!e&&(m=b.get(f)))return[2,m];n=u.headers;l&&(l instanceof FormData||l instanceof Blob||l instanceof ArrayBuffer)||(n=__assign({"Content-Type":"application/json; charset=utf-8"},u.headers));r=n&&n["Content-Type"]&&-1!==n["Content-Type"].indexOf("json");
x=a.fetch||fetch;return[4,x(h,__assign(__assign({},u),{body:l?r?JSON.stringify(l):l:void 0,headers:n}))];case 2:return p=k.sent(),y=d,z=[g],v={error:!p.ok,headers:p.headers},[4,resolveResponse(p,t)];case 3:return[4,y.apply(void 0,z.concat([(v.payload=k.sent(),v.status=p.status,v),a.responseInterceptors||[]]))];case 4:q=k.sent();b&&p.ok&&b.add(f,q);if(q.status&&g.config&&g.config.emitErrorForStatuses&&g.config.emitErrorForStatuses.includes(q.status))throw new QueryError("request-error",q);return[2,
q];case 5:return A=k.sent(),[2,{error:!0,errorObject:A}];case 6:return[2]}})})},suspenseCache:f};return h};
function resolveResponse(a,b){return __awaiter(this,void 0,void 0,function(){var f,c,d,h;return __generator(this,function(g){switch(g.label){case 0:return b?[2,a[b]()]:[3,1];case 1:return f=[204,205],c=a.headers.get("Content-Type"),(d=-1===f.indexOf(a.status)&&c&&-1!==c.indexOf("json"))?[4,a.json()]:[3,3];case 2:return h=g.sent(),[3,5];case 3:return[4,a.text()];case 4:h=g.sent(),g.label=5;case 5:return[2,h]}})})}
var initialContext={query:function(){console.warn("Add ClientProvider to use client context");return Promise.resolve({error:!0,status:0})},suspenseCache:createCache(function(){return!0},function(){return!0})},ClientContext=React.createContext(initialContext),SET_LOADING="response/loading",RESET_LOADING="response/reset-loading",RESET="response/reset",SET_RESPONSE="response/set",responseReducer=function(a,b){switch(b.type){case SET_LOADING:return __assign(__assign({},a),{loading:!0});case RESET_LOADING:return __assign(__assign({},
a),{loading:!1});case SET_RESPONSE:if(!b.response)throw Error();return __assign(__assign({},a),{loading:!1,response:b.response});case RESET:return{loading:!1,response:{error:!1}};default:throw Error();}},useCachedResponse=function(a){var b=React.useContext(ClientContext);if(b.cache)return b.cache.get(a)},useQuery=function(a,b){void 0===b&&(b=!0);var f=React.useContext(ClientContext),c=useCachedResponse(a),d=React.useRef(!0),h=React.useRef(),g=React.useReducer(responseReducer,{loading:c?!1:b,response:c?
c:{error:!1}}),e=g[0],k=g[1];React.useEffect(function(){d.current=!0;b&&!c&&w();return function(){d.current=!1;l()}},[convertActionToBase64(a)]);var w=React.useCallback(function(c){void 0===c&&(c=!1);return __awaiter(void 0,void 0,void 0,function(){var b,g,e;return __generator(this,function(l){switch(l.label){case 0:b="AbortController"in window?new AbortController:void 0;g=a.signal||(b?b.signal:void 0);h.current&&h.current.abort();h.current=b;if(!d.current)return[2,{error:!1}];k({type:SET_LOADING});
return[4,f.query(__assign(__assign({},a),{signal:a.signal||g}),c)];case 1:return e=l.sent(),!d.current||e.errorObject&&"AbortError"===e.errorObject.name||k({type:SET_RESPONSE,response:e}),d.current&&e.errorObject&&"AbortError"===e.errorObject.name&&h.current&&h.current===b&&(h.current=void 0,k({type:RESET_LOADING})),[2,e]}})})},[convertActionToBase64(a)]);g=React.useCallback(function(){return w(!0)},[convertActionToBase64(a)]);var l=React.useCallback(function(){h.current&&h.current.abort()},[]),t=
React.useCallback(function(){k({type:RESET})},[]);if(e.response&&e.response.errorObject&&e.response.errorObject instanceof QueryError)throw e.response.errorObject;return __assign({abort:l,loading:e.loading,query:g,reset:t},e.response)},useMutation=function(a){var b=React.useContext(ClientContext),f=React.useRef(!0),c=React.useRef(),d=React.useReducer(responseReducer,{loading:!1,response:{error:!1}}),h=d[0],g=d[1];React.useEffect(function(){f.current=!0;return function(){f.current=!1;e()}},[]);d=React.useCallback(function(){for(var e=
[],d=0;d<arguments.length;d++)e[d]=arguments[d];return __awaiter(void 0,void 0,void 0,function(){var d,h,l,k;return __generator(this,function(r){switch(r.label){case 0:if(!f.current)return[2,{error:!1}];d=a.apply(void 0,e);h="AbortController"in window?new AbortController:void 0;l=d.signal||(h?h.signal:void 0);c.current&&c.current.abort();c.current=h;g({type:SET_LOADING});return[4,b.query(__assign(__assign({},d),{signal:d.signal||l}))];case 1:return k=r.sent(),!f.current||k.errorObject&&"AbortError"===
k.errorObject.name||g({type:SET_RESPONSE,response:k}),f.current&&k.errorObject&&"AbortError"===k.errorObject.name&&c.current&&c.current===h&&(c.current=void 0,g({type:RESET_LOADING})),[2,k]}})})},[a]);var e=React.useCallback(function(){c.current&&c.current.abort()},[]),k=React.useCallback(function(){g({type:RESET})},[]);if(h.response&&h.response.errorObject&&h.response.errorObject instanceof QueryError)throw h.response.errorObject;return __assign({abort:e,loading:h.loading,mutate:d,reset:k},h.response)},
useBulkMutation=function(a){var b=React.useContext(ClientContext).query,f=React.useRef(!0),c=React.useRef(),d=React.useState({loading:!1,responses:[]}),h=d[0],g=d[1],e=React.useCallback(function(){c.current&&c.current.abort()},[c]);React.useEffect(function(){f.current=!0;return function(){f.current=!1;e()}},[e]);d=React.useCallback(function(d){return __awaiter(void 0,void 0,void 0,function(){var e,h,k,m;return __generator(this,function(l){switch(l.label){case 0:if(!f.current)return[2,Array.from(Array(10).keys()).map(function(){return{error:!1}})];
e="AbortController"in window?new AbortController:void 0;h=d.map(function(b){return a(b)});k=e?e.signal:void 0;h.forEach(function(a){return a.signal=a.signal||k});c.current&&c.current.abort();c.current=e;g(function(a){return __assign(__assign({},a),{loading:!0})});return[4,Promise.all(h.map(function(a){return b(a)}))];case 1:return m=l.sent(),f.current&&g({loading:!1,responses:m.map(function(a,b){if(!a.errorObject||"AbortError"!==a.errorObject.name)return h[b].signal===k&&c.current===e&&(c.current=
void 0,g(function(a){return __assign(__assign({},a),{loading:!1})})),a})}),[2,m]}})})},[b,a]);var k=React.useCallback(function(){g({loading:!1,responses:[]})},[g]);return{abort:e,loading:h.loading,mutate:d,reset:k,responses:h.responses}},useSuspenseQuery=function(a){var b=React.useContext(ClientContext),f=React.useState(null),c=f[0],d=f[1],h=b.suspenseCache.get(a);React.useEffect(function(){h&&h.response&&null!==c&&b.suspenseCache.remove(a);return function(){b.suspenseCache.remove(a)}},[convertActionToBase64(a)]);
f=function(){b.suspenseCache.remove(a);d(!c)};if(h){if(h.response){if(h.response.errorObject&&h.response.errorObject instanceof QueryError)throw h.response.errorObject;return __assign(__assign({},h.response),{query:f})}throw h.fetch;}var g=b.query(a,null!==c).then(function(c){b.suspenseCache.add(a,{fetch:g,response:c})});b.suspenseCache.add(a,{fetch:g});throw g;},useClient=function(){return React.useContext(ClientContext)},useParameterizedQuery=function(a){var b=useMutation(a);a=b.mutate;b=__rest(b,
["mutate"]);return __assign(__assign({},b),{query:a})},Query=function(a){var b=a.children,f=a.initFetch;a=useQuery(a.action,void 0===f?!0:f);return b(a)},Mutation=function(a){var b=a.children;a=useMutation(a.actionCreator);return b(a)},SuspenseQuery=function(a){var b=a.children;a=useSuspenseQuery(a.action);return b(a)},QueryErrorBoundary=function(a){function b(b){var c=a.call(this,b)||this;c.state={hasError:!1};c.restart=function(){c.setState({hasError:!1,response:void 0})};c.state={hasError:!1,response:void 0};
return c}__extends(b,a);b.getDerivedStateFromError=function(a){if(a instanceof QueryError)return{hasError:!0,response:a.response}};b.prototype.render=function(){return this.state.hasError&&this.state.response&&this.state.response.status&&this.props.statuses.includes(this.state.response.status)?this.props.fallback(this.state.response,this.restart):this.props.children};return b}(React.Component),ClientContextProvider=function(a){var b=a.client;return React__default.createElement(ClientContext.Provider,
{value:{query:b.query,cache:b.cache,suspenseCache:b.suspenseCache}},a.children)};exports.ClientContext=ClientContext;exports.ClientContextProvider=ClientContextProvider;exports.Mutation=Mutation;exports.Query=Query;exports.QueryError=QueryError;exports.QueryErrorBoundary=QueryErrorBoundary;exports.SuspenseQuery=SuspenseQuery;exports.convertActionToBase64=convertActionToBase64;exports.createCache=createCache;exports.createClient=createClient;exports.useBulkMutation=useBulkMutation;
exports.useCachedResponse=useCachedResponse;exports.useClient=useClient;exports.useMutation=useMutation;exports.useParameterizedQuery=useParameterizedQuery;exports.useQuery=useQuery;exports.useSuspenseQuery=useSuspenseQuery;
